@@ -121,9 +121,15 @@ def read_IFS(indicator, ref_area, frequency='M', startPeriod=None, endPeriod=Non
 """==========================================================================================================
 DATAFILE contains the raw data to be filtered
 """
-DATAFILE = r"macrodemos\data\IFS_GDP.xlsx"
+DATAFILE = r"data\IFS_GDP.xlsx"
+
+try:
+    AVAILABLE_COUNTRIES = pd.read_excel(DATAFILE, 'Countries')
+except:
+    DATAFILE = 'macrodemos\\' + DATAFILE
+    AVAILABLE_COUNTRIES = pd.read_excel(DATAFILE, 'Countries')
+
 
-AVAILABLE_COUNTRIES = pd.read_excel(DATAFILE, 'Countries')
 AVAILABLE_COUNTRIES.set_index(['ISO', 'NAME'], inplace=True)
 AVAILABLE_COUNTRIES = AVAILABLE_COUNTRIES[AVAILABLE_COUNTRIES.sum(axis=1)>0]
 AVAILABLE_COUNTRIES = AVAILABLE_COUNTRIES.astype(bool)
@@ -517,7 +523,7 @@ def update_plots(n_clicks, indicator, whichFilters, lambda_, K, pL, pH, cfpL, cf
         comovement = go.Figure()
 
     trend.update_layout(title_text=f'Trend: {indicator} in {country}', xaxis_rangeslider_visible=True, height=700)
-    cycle.update_layout(title_text=f'Cycle: {indicator} in {country}', xaxis_rangeslider_visible=True, height=700)
+    cycle.update_layout(title_text=f'Cycle: {indicator} in {country}', xaxis_rangeslider_visible=True, height=700, yaxis_title="% deviation from trend")
     comovement.update_layout(title_text=f'Comovement: {indicator} in {country}', height=700)
 
     return trend, cycle, comovement
